summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorGanga Negi <ganga.negi@freescale.com>2013-12-27 12:07:48 (GMT)
committerEmilian Medve <Emilian.Medve@freescale.com>2014-01-17 19:52:58 (GMT)
commitd191e51acb0c1876dfb98936cdaec34627b6f5e2 (patch)
treec04b8caaa43937544da2feb826d4269adf7579f0 /include
parente154b82a45804b322c1ddfa7fade625ed1ac2733 (diff)
downloadlinux-fsl-qoriq-d191e51acb0c1876dfb98936cdaec34627b6f5e2.tar.xz
fsl_qman: Fix CEETM APIs spelling
Also fix some parameters type mismatch Signed-off-by: Ganga Negi <ganga.negi@freescale.com> Change-Id: I2f7b6951220732bec0791c1d7550ba78183d4882 Reviewed-on: http://git.am.freescale.net:8181/8083 Tested-by: Review Code-CDREVIEW <CDREVIEW@freescale.com> Reviewed-by: Emilian Medve <Emilian.Medve@freescale.com>
Diffstat (limited to 'include')
-rw-r--r--include/linux/fsl_qman.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/include/linux/fsl_qman.h b/include/linux/fsl_qman.h
index 5d84735..89721b9 100644
--- a/include/linux/fsl_qman.h
+++ b/include/linux/fsl_qman.h
@@ -2883,30 +2883,30 @@ int qman_ceetm_channel_get_group(struct qm_ceetm_channel *channel,
/**
* qman_ceetm_channel_set_group_cr_eligibility
- * qman_ceetm_channel_set_group_er_eligibility - Set channel group eligibitity
+ * qman_ceetm_channel_set_group_er_eligibility - Set channel group eligibility
* @channel: the given channel object
* @group_b: indicates whether there is group B in this channel.
* @cre: the commit rate eligibility, 1 for enable, 0 for disable.
*
* Return zero for success, or -EINVAL if eligiblity setting fails.
*/
-int qman_ceetm_channel_set_group_cr_eligiblility(struct qm_ceetm_channel
+int qman_ceetm_channel_set_group_cr_eligibility(struct qm_ceetm_channel
*channel, int group_b, int cre);
-int qman_ceetm_channel_set_group_er_eligiblility(struct qm_ceetm_channel
+int qman_ceetm_channel_set_group_er_eligibility(struct qm_ceetm_channel
*channel, int group_b, int ere);
/**
* qman_ceetm_channel_set_cq_cr_eligibility
- * qman_ceetm_channel_set_cq_er_eligibility - Set channel cq eligibitity
+ * qman_ceetm_channel_set_cq_er_eligibility - Set channel cq eligibility
* @channel: the given channel object
* @idx: is from 0 to 7 (representing CQ0 to CQ7).
* @cre: the commit rate eligibility, 1 for enable, 0 for disable.
*
* Return zero for success, or -EINVAL if eligiblity setting fails.
*/
-int qman_ceetm_channel_set_cq_cr_eligiblility(struct qm_ceetm_channel *channel,
+int qman_ceetm_channel_set_cq_cr_eligibility(struct qm_ceetm_channel *channel,
unsigned int idx, int cre);
-int qman_ceetm_channel_set_cq_er_eligiblility(struct qm_ceetm_channel *channel,
+int qman_ceetm_channel_set_cq_er_eligibility(struct qm_ceetm_channel *channel,
unsigned int idx, int ere);
/* --------------------- */
@@ -2883,30 +2883,30 @@ int qman_ceetm_channel_get_group(struct qm_ceetm_channel *channel,
* @cre: the commit rate eligibility, 1 for enable, 0 for disable.
*
- * Return zero for success, or -EINVAL if eligiblity setting fails.
+ * Return zero for success, or -EINVAL if eligibility setting fails.
*/
@@ -2883,30 +2883,30 @@ int qman_ceetm_channel_get_group(struct qm_ceetm_channel *channel,
* @cre: the commit rate eligibility, 1 for enable, 0 for disable.
*
- * Return zero for success, or -EINVAL if eligiblity setting fails.
+ * Return zero for success, or -EINVAL if eligibility setting fails.
*/